==> moniwiki-1.0.tgz: moniwiki/plugin/Admin.php <==
<?
function do_admin($formatter,$options) {
  global $DBInfo;

  print "<h1>Under Construction</h1>";
  if ($options[delete_page]) {
    print "<pre class='console'>\n";
    foreach($options[seeds] as $seed) {
      $key=$DBInfo->pageToKeyname($seed);
      $cmd="rm -f $DBInfo->text_dir/$key $DBInfo->text_dir/RCS/$key,v";
      #system(escapeshellcmd($cmd));
      print $cmd."\n";
    }
    print "</pre>\n";
    return;
  }

  $pages= array();
  $handle= opendir($DBInfo->text_dir);
  while ($file = readdir($handle)) {
    if (is_dir($DBInfo->text_dir."/".$file)) continue;
    $pagename = $DBInfo->keyToPagename($file);
    $pages[$pagename] = $pagename;
  }
  closedir($handle);
#  sort($pages);
  $idx=1;

  $num=sizeof($pages);

  #
  $SystemPages="FrontPage|RecentChanges|TitleIndex|FindPage|".
  "FortuneCookies|Pages$|".
  "SystemPages|TwinPages|WikiName|SystemInfo|UserPreferences|".
  "InterMap|IsbnMap|WikiSandBox|SandBox|UploadFile|UploadedFiles|".
  "InterWiki|SandBox|UploadFile|UploadedFiles|".
  "Ű|Ű|ġ|ֵ|ڸŰ|Ű";
  $WikiTag='DeleteThisPage';
  #
  $seed_filters= array(
    "HelpPages"=>array('/^Help.*/',0),
    "Category pages"=>array('/^Category.*/',0),
    "Macro pages"=>array('/Macro$/',0),
    "MoniWiki pages"=>array('/MoniWiki.*|Moni/',0),
    "MoinMoin pages"=>array('/MoinMoin.*/',1),
    "Templates"=>array('/Template$/',0),
    "SystemPages"=>array("/($SystemPages)/",0),
    "WikiTags"=>array("/($WikiTag)/",0),
    "Wiki etc."=>array('/Wiki/',1),
    "Misc."=>array('//',1),
  );

  $wrap=1;

  print "<h3>Total $num pages found</h3>\n";
  print "<form method='post' action=''>\n";
  while (list($filter_name,$filter) = each($seed_filters)) {
    print "<h4>$filter_name</h4>\n";
    foreach ($pages as $pagename) {
      if (preg_match($filter[0],$pagename)) {
        print "<input type='checkbox' name='seeds[$idx]' value='$pagename'";
        if ($filter[1])
          print "checked='checked' />".$formatter->link_tag(_rawurlencode($pagename),"",$pagename);
        else
          print " />".$formatter->link_tag(_rawurlencode($pagename),"",$pagename);
        $idx++;
        if ($wrap++ % 4 == 0) print "<br />\n";
        unset($pages[$pagename]);
      }
    }
    $wrap=1;
  }
  print "<input type='hidden' name='action' value='Admin' />\n";
  print "<br /><input type='submit' name='delete_page' value='delete pages'></form>\n";
}
?>

==> moniwiki-1.0.2.tgz: moniwiki/plugin/Admin.php <==
<?
// Copyright 2003 by Won-Kyu Park <wkpark at kldp.org>
// All rights reserved. Distributable under GPL see COPYING
// a Admin action plugin for the MoniWiki
// vim:et:ts=2:
//
// $Id: Admin.php,v 1.2 2003/08/15 21:30:36 wkpark Exp $
function do_admin($formatter,$options) {
  global $DBInfo;

  print "<h1>Under Construction</h1>";
  if ($options['delete_page']) {
    print "<pre class='console'>\n";
    foreach($options['seeds'] as $seed) {
      $key=$DBInfo->pageToKeyname($seed);
      $cmd="rm -f $DBInfo->text_dir/$key $DBInfo->text_dir/RCS/$key,v";
      #system(escapeshellcmd($cmd));
      print $cmd."\n";
    }
    print "</pre>\n";
    return;
  }

  $pages= array();
  $handle= opendir($DBInfo->text_dir);
  while ($file = readdir($handle)) {
    if (is_dir($DBInfo->text_dir."/".$file)) continue;
    $pagename = $DBInfo->keyToPagename($file);
    $pages[$pagename] = $pagename;
  }
  closedir($handle);
#  sort($pages);
  $idx=1;

  $num=sizeof($pages);

  #
  $SystemPages="FrontPage|RecentChanges|TitleIndex|FindPage|".
  "FortuneCookies|Pages$|".
  "SystemPages|TwinPages|WikiName|SystemInfo|UserPreferences|".
  "InterMap|IsbnMap|WikiSandBox|SandBox|UploadFile|UploadedFiles|".
  "InterWiki|SandBox|UploadFile|UploadedFiles|".
  $WikiTag='DeleteThisPage';
  #
  $seed_filters= array(
    "HelpPages"=>array('/^Help.*/',0),
    "Category pages"=>array('/^Category.*/',0),
    "Macro pages"=>array('/Macro$/',0),
    "MoniWiki pages"=>array('/MoniWiki.*|Moni/',0),
    "MoinMoin pages"=>array('/MoinMoin.*/',1),
    "Templates"=>array('/Template$/',0),
    "SystemPages"=>array("/($SystemPages)/",0),
    "WikiTags"=>array("/($WikiTag)/",0),
    "Wiki etc."=>array('/Wiki/',1),
    "Misc."=>array('//',1),
  );

  $wrap=1;

  print "<h3>Total $num pages found</h3>\n";
  print "<form method='post' action=''>\n";
  while (list($filter_name,$filter) = each($seed_filters)) {
    print "<h4>$filter_name</h4>\n";
    foreach ($pages as $pagename) {
      if (preg_match($filter[0],$pagename)) {
        print "<input type='checkbox' name='seeds[$idx]' value='$pagename'";
        if ($filter[1])
          print "checked='checked' />".$formatter->link_tag(_rawurlencode($pagename),"",$pagename);
        else
          print " />".$formatter->link_tag(_rawurlencode($pagename),"",$pagename);
        $idx++;
        if ($wrap++ % 4 == 0) print "<br />\n";
        unset($pages[$pagename]);
      }
    }
    $wrap=1;
  }
  print "<input type='hidden' name='action' value='Admin' />\n";
  print "<br /><input type='submit' name='delete_page' value='delete pages'></form>\n";
}
?>
